<?php

namespace TurboSMSWoocommerceViberEdition;

/**
 * Class Plugin
 * @package TurboSMSWoocommerceViberEdition
 */
class Plugin
{

	/**
	 * Run
	 */
	function run()
	{
		add_action('plugins_loaded', array($this, 'load_textdomain'));
		add_action('admin_enqueue_scripts', array($this, 'assets'));
		add_action('wp_ajax_Block_SMS_In_Order_send', array($this, 'send'));
		add_action('add_meta_boxes', array($this, 'register_metabox'));
		$updateChecker = \Puc_v4_Factory::buildUpdateChecker(
			'https://plugin.freelancevip.pro/turbosms-woocommerce-viber-edition/details.php',
			dirname(__FILE__) . '/turbosms-woocommerce-viber-edition.php',
			TWVE_SLUG
		);
		$updateChecker->addQueryArgFilter([$this, 'wsh_filter_update_checks']);
	}

	function wsh_filter_update_checks($queryArgs)
	{
		$queryArgs['domain'] = get_home_url();

		return $queryArgs;
	}

	/**
	 * i18n
	 */
	function load_textdomain()
	{
		load_plugin_textdomain(
			'turbosms-woocommerce-viber-edition',
			false,
			'/turbosms-woocommerce-viber-edition/languages'
		);
	}

	/**
	 * Аякс отправка СМС с сайдбара
	 */
	function send()
	{
		$to       = self::sanitize_phone($_POST['phone']);
		$text     = $_POST['text'];
		$order_id = intval($_POST['order_id']);

		$order  = wc_get_order($order_id);
		$status = $order->get_status();

		$text = apply_filters('twve_user_message', $text, $order, $order_id, $status);

		$settings    = Settings::get_instance();
		$smsSender   = $settings->get_setting('sms_sender');
		$viberSender = $settings->get_setting('viber_sender');
		$token       = $settings->get_setting('http_api_token');
		$send_method = $settings->get_setting('send_method');

		$api = Api::get_instance()->init($smsSender, $viberSender, $token);
		$result = $api->sendMessage($text, $to, $send_method);

		if (is_array($result)) {
			$order->add_order_note($text, true);
			$message = $result[0]->response_status;
		} else {
			$message = $result;
		}

		wp_send_json(array('message' => $message));
	}

	/**
	 * Register metabox
	 */
	function register_metabox()
	{
		add_meta_box(
			'Block_SMS_In_Order',
			__('TurboSMS'),
			array($this, 'render_metabox'),
			'shop_order',
			'side'
		);
	}

	/**
	 * Отображение метабокса
	 */
	function render_metabox()
	{
		$user_phone = '+380';
		if (get_post_type() === 'shop_order') {
			$order      = wc_get_order(get_the_ID());
			$user_phone = $order->get_billing_phone();
			$user_phone = self::sanitize_phone($user_phone);
		}
?>
		<div id="Block_SMS_In_Order_form">
			<p><input type="text" name="phone" value="<?php echo $user_phone ?>" class="widefat" placeholder="Phone" aria-label="phone"></p>
			<p><textarea name="sms" id="" rows="3" placeholder="Текст SMS" class="widefat" aria-label="text"></textarea></p>
			<input type="hidden" value="<?php the_ID(); ?>" name="woocommerce-order-id">
			<?php MessagePatterns::the_popup_button_html(); ?>
			<button id="Block_SMS_In_Order__go" class="button button-small">
				<?php _e('Send SMS / Viber', 'turbosms-woocommerce-viber-edition') ?>
			</button>
			<div id="Block_SMS_In_Order_form__res"></div>
		</div>
<?php
		MessagePatterns::the_popup_html();
	}

	/**
	 * Скрипты и стили плагина
	 *
	 * @param $hook
	 */
	function assets($hook)
	{
		// For settings page
		if ($hook === 'plugins_page_turbosms-woocommerce-viber-edition') {
			wp_enqueue_style(
				'bootstrap-css',
				TWVE_URL . '/css/bootstrap.min.css',
				null,
				TWVE_VERSION
			);
			wp_enqueue_style(
				self::class,
				TWVE_URL . '/css/style.css',
				null,
				TWVE_VERSION
			);
		}

		wp_enqueue_script(
			'TurboSMS_Woocommerce_In_Order',
			plugins_url('/js/main.js', __FILE__),
			'jquery',
			TWVE_VERSION
		);
	}

	public static function sanitize_phone($phone)
	{
		$need_ukrainian_phone = true;
		$need_ukrainian_phone = apply_filters('twve_need_ukrainian_phone', $need_ukrainian_phone);
		if (!$need_ukrainian_phone) {
			return $phone;
		}
		$phone = preg_replace('/[^0-9]/', '', $phone);
		$len = strlen($phone);

		if ($len === 12) {
			$phone = '+' . $phone;
		} elseif ($len === 11) {
			$phone = '+3' . $phone;
		} else {
			$phone = '+38' . $phone;
		}

		return $phone;
	}

	private static $instance = null;

	public static function get_instance()
	{
		if (null === self::$instance) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	private function __clone()
	{
	}

	private function __construct()
	{
	}
}
