<?php

namespace TurboSMSWoocommerceViberEdition;

/**
 * Class Filters
 * @package TurboSMSWoocommerceViberEdition
 * Filters:
 * 'twve_user_message'
 * 'twve_admin_message'
 * Пример filters:
 * add_filter( 'twve_user_message', 'my_user_message', 10, 4 );
 * function my_user_message($message, $order, $order_id, $status) {
 *  // add some functionality
 *  return $message;
 * }
 * @since 1.0.0
 */
final class Filters {

	private $templates = array(
		'order_id',
		'first_name',
		'last_name',
		'status',
		'total',
		'currency',
		'billing_postcode',
		'items_names',
		'shipping_total',
		'payment_method',
		'num',
		'billing_phone',
		'billing_company',
		'billing_address_1',
		'billing_address_2',
		'billing_city',
		'billing_state',
		'billing_postcode',
		'billing_country',
		'billing_email',
	);

	function __construct() {
		add_filter( 'twve_user_message', [ $this, 'before_message' ], 10, 4 );
		add_filter( 'twve_admin_message', [ $this, 'before_message' ], 10, 4 );
		add_filter( 'twve_need_ukrainian_phone', '__return_true', 10 );
		add_filter( 'puc_manual_check_link-turbosms-woocommerce-viber-edition', [
			$this,
			'puc_manual_check_link_text'
		], 10 );
	}

	function puc_manual_check_link_text( $text ) {
		return __( 'Check for updates', 'turbosms-woocommerce-viber-edition' );
	}

	/**
	 * @param $message string
	 * @param $order \WC_Order
	 * @param $order_id int
	 * @param $status string
	 *
	 * @return string
	 */
	function before_message( $message, $order, $order_id, $status ) {
		$data             = $order->get_data();
		$currency         = $data['currency'];
		$billing_postcode = $order->get_billing_postcode();

		$total = $order->get_total();

		$order_items = $order->get_items();
		$items_names = '';
		foreach ( $order_items as $item ) {
			$items_names .= $item->get_name() . ', ';
		}
		$items_names = rtrim( $items_names, ', ' );

		// variable names same as $this->templates names
		$first_name        = $order->get_billing_first_name();
		$last_name         = $order->get_billing_last_name();
		$shipping_total    = $order->get_shipping_total();
		$payment_method    = $order->get_payment_method_title();
		$num               = $order->get_order_number();
		$billing_phone     = $order->get_billing_phone();
		$billing_company   = $order->get_billing_company();
		$billing_address_1 = $order->get_billing_address_1();
		$billing_address_2 = $order->get_billing_address_2();
		$billing_city      = $order->get_billing_city();
		$billing_state     = $order->get_billing_state();
		$billing_postcode  = $order->get_billing_postcode();
		$billing_country   = $order->get_billing_country();
		$billing_email     = $order->get_billing_email();

		foreach ( $this->templates as $template ) {
			$message = str_replace( "%$template%", $$template, $message );
		}

		// Order meta
		$message = preg_replace_callback( '!\%#([^#]+)#\%!',
			function ( $matches ) use ( $order_id ) {
				return $this->replace_meta( $matches, $order_id );
			},
			$message );

		return $message;
	}

	function replace_meta( $matches, $order_id ) {
		if (
			( class_exists( 'kirillbdev\WCUkrShipping\Pro\WCUkrShippingPro' ) || class_exists( '\kirillbdev\WCUkrShipping\Classes\WCUkrShipping' ) )
			&& $matches[1] === 'novaposhta_ttn' ) {
			global $wpdb;

			return $wpdb->get_var( "
			SELECT ttn_id
			FROM wc_ukr_shipping_np_ttn
			WHERE order_id = '" . (int) $order_id . "'
		" );
		}
		$meta = get_post_meta( $order_id, $matches[1], true );
		if ( ! $meta || is_array( $meta ) || empty( $meta ) ) {
			return '-';
		}

		return $meta;
	}
}
