<?php

namespace TurboSMSWoocommerceViberEdition;

final class MessagePatterns {

	private static $patternKeys = [
		'pattern-1',
		'pattern-2',
		'pattern-3',
		'pattern-4',
		'pattern-5',
	];

	/**
	 * @return string[]
	 */
	public static function get_pattern_keys() {
		return self::$patternKeys;
	}

	public static function get_pattern_text( $key ) {
		$patterns = get_option( 'twve_patterns',
			array_fill_keys( self::get_pattern_keys(), '' ) );

		return $patterns[ $key ];
	}

	public static function the_popup_html() {
		add_thickbox();
		?>
        <div id="twve-message-patterns-popup" style="display:none;">
            <div id="twve-message-patterns-popup-content">
                <div>
                    <table class="widefat" style="margin: 10px 0;">
						<?php
						foreach ( self::get_pattern_keys() as $key ):
							?>
                            <tr>
                                <td width="250">
                                    <textarea name="<?php echo $key ?>" rows="3"
                                              class="widefat"><?php echo self::get_pattern_text( $key ) ?></textarea>
                                </td>
                                <td>
                                    <button class="button-group button button-primary twve-insert-message-pattern"><span
                                                class="dashicons dashicons-saved"></span></button>
                                </td>
                            </tr>
						<?php endforeach; ?>
                    </table>
                    <div>
                        <button class="button button-primary twve-update-message-patterns"><?php _e( 'Update',
								'woocommerce' ) ?></button>
                    </div>
                </div>
            </div>
        </div>
		<?php
	}

	public static function the_popup_button_html() {
		?>
        <a title="<?php _e( 'TurboSMS message patterns',
			'turbosms-woocommerce-viber-edition' ) ?>"
           href="#TB_inline?&width=350&height=400&inlineId=twve-message-patterns-popup"
           id="turbosms-message-patterns" class="button button-small button-link thickbox"><?php _e( 'Patterns',
				'turbosms-woocommerce-viber-edition' ) ?></a>
		<?php
	}


	function run() {
		if ( is_admin() ) {
			add_action( 'wp_ajax_twve-save-message-patterns', array( $this, 'save_patterns' ) );
		}
	}

	function save_patterns() {
		$keys = self::get_pattern_keys();
		$data = array();
		foreach ( $keys as $key ) {
			$data[ $key ] = sanitize_text_field( $_POST[ $key ] );
		}
		update_option( 'twve_patterns', $data );
		wp_send_json_success();
	}

	private static $instance = null;

	public static function get_instance() {
		if ( null === self::$instance ) {
			self::$instance = new self();
		}

		return self::$instance;
	}

	private function __clone() {
	}

	private function __construct() {
	}
}